@@ -104,7 +104,7 @@ class PropensityRunner(BaseRunner):
                 staging=staging,
                 encoding=encoding,
             )
-            res['data2'] = res['data2'].append(res5['data2'])
+            res['data2'] = pd.concat([res['data2'], res5['data2']])
             idx += 1
         return res
 
@@ -133,17 +133,23 @@ class PropensityRunner(BaseRunner):
         request_id = self._get_request_id()
 
         if encoding:
-            keys = self._keys_load(model_id=model_id, verbose=verbose) # Load encoding keys
+
+            # Load encoding keys
+            keys = self._keys_load(model_id=model_id, verbose=verbose) 
             if keys is None:
                 print('ERROR! Keys not found. ')
                 return None
+
+            # Encode data 
             data, xref, zref, rref, fref, fref_exp, bref = self._encode(
                 df, keys=keys, categorical_vars=categorical_vars,
                 numerical_vars=numerical_vars, bool_vars=bool_vars,
                 record_id_var=idx_var, verbose=verbose)
             if verbose: print('Total rows encoded: {:,}'.format(len(data)))
+
         else:
-            data = df
+
+            data = deepcopy(df)
 
         # Save data to buffer
         res = self._buffer_save(
@@ -175,21 +181,25 @@ class PropensityRunner(BaseRunner):
                     },
                 timeout=timeout,
                 step=step,
-                verbose=verbose)
+                verbose=verbose, 
+            )
             data2 = self.__retrieve_predict_results(
                 request_id=request_id,
                 client_id=client_id,
-                verbose=verbose)
+                verbose=verbose, 
+            )
         else:
             print('ERROR! Buffer save failed: {}'.format(res))
 
         # Clear buffer
         res4 = self._buffer_clear(
-            request_id=res['request_id'], client_id=client_id,
-            verbose=verbose)
+            request_id=res['request_id'], 
+            client_id=client_id,
+            verbose=verbose, 
+        )
 
         # Decode data
-        if encoding:
+        if encoding is True:
             data2 = self._decode(
                 data2,
                 categorical_vars=categorical_vars,
@@ -201,7 +211,7 @@ class PropensityRunner(BaseRunner):
                 rref=rref,
                 fref=fref,
                 bref=bref,
-                verbose=verbose
+                verbose=verbose, 
             )
 
         # Compile results
@@ -315,7 +325,7 @@ class PropensityRunner(BaseRunner):
             bool_vars=[], algorithm='random-forest-classifier', train_size=0.5,
             buffer_batch_size=1000, verbose=False, timeout=600, step=2, poll=True,
             smote=False, param_grid=None, scoring=None, n_splits=None,
-            compressed=False, staging=True, encoding=True):
+            compressed=False, staging=True, encoding=True, out_of_core=False):
         """
         Train propensity model on user-provided dataset
 
@@ -389,6 +399,9 @@ class PropensityRunner(BaseRunner):
         :param encoding: encode and decode data with homomorphic encryption.
             Defaults to `True`
         :type encoding: boolean, optional
+        :param out_of_core: determines whether the model is going to be trained out of core or not. 
+            Defaults to `False`
+        :type out_of_core: boolean, optional
         :return: JSON object with the following attributes, as applicable:
                     `model_id` (UUID provided with initial request),
                     `features` (table of feature importances),
@@ -398,14 +411,18 @@ class PropensityRunner(BaseRunner):
                     `roc` (receiver operating characteristic curve)
         """
 
-        # Encode data
         request_id = self._get_request_id()
         if verbose: print('Model ID: {}'.format(request_id))
+
         if encoding:
+
+            # Encode data
             data, xref, zref, rref, fref, fref_exp, bref = self._encode(
                 df, categorical_vars=categorical_vars,
                 numerical_vars=numerical_vars, bool_vars=bool_vars,
                 record_id_var=idx_var, verbose=verbose)
+
+            # Save encoding keys locally
             self._keys_save(
                 model_id=request_id,
                 keys={
@@ -417,8 +434,10 @@ class PropensityRunner(BaseRunner):
                     'bref': bref
                 },
                 verbose=verbose) # Save encoding keys locally
+
         else:
-            data = df
+
+            data = deepcopy(df)
 
         # Save encoded data to buffer
         res = self._buffer_save(
@@ -441,6 +460,7 @@ class PropensityRunner(BaseRunner):
                 param_grid=param_grid,
                 scoring=scoring,
                 n_splits=n_splits,
+                out_of_core=out_of_core, 
             )
             if poll:
                 res2 = self._poll(
@@ -484,7 +504,7 @@ class PropensityRunner(BaseRunner):
             idx_field=None, outcome_var=None, categorical_fields=[],
             algorithm='random-forest-classifier', train_size=0.5, smote=False,
             param_grid=None, scoring=None, n_splits=None,
-            verbose=False, staging=False):
+            verbose=False, staging=False, out_of_core=False):
         """
         :param request_id:
         :param client_id: Short name for account being used. Used for reporting
@@ -501,6 +521,7 @@ class PropensityRunner(BaseRunner):
         :param param_grid:
         :param scoring:
         :param n_splits:
+        :param out_of_core:
         :return:
         """
         if verbose: print('Training propensity model using data in buffer...')
@@ -518,6 +539,7 @@ class PropensityRunner(BaseRunner):
             'param_grid': param_grid,
             'scoring': scoring,
             'n_splits': n_splits,
+            'out_of_core': out_of_core, 
         })
         if verbose: print('Training request posted.')
         return res
@@ -546,7 +568,7 @@ class PropensityRunner(BaseRunner):
         if not features.empty:
             features['Importance'] = features['Importance'].astype('float')
             features.sort_values(by=['Importance'], ascending=False, inplace=True)
-            if encoding:
+            if encoding is True:
                 for idx, row in features.iterrows():
                     features.loc[idx, 'Feature'] = fref_decode_value(
                         features.loc[idx, 'Feature'],
