@@ -1,5 +1,5 @@
 """
-Copyright (c) 2020-2021 Go2Market Insights, LLC
+Copyright (c) 2024 Go2Market Insights, Inc
 All rights reserved.
 https://g2m.ai
 
@@ -133,6 +133,22 @@ def zref_decode(series, zref):
 
     return series2
 
+def zref_decode_first_derivative_value(val, zref_x, zref_y):
+    """
+    Replaces z scores in a Series with denormalized numerical values. 
+    Applies to first derivative of variable y with respect to variable 
+    x, such as coefficients for linear regression. 
+
+    :param val:
+    :param zref_x:
+    :param zref_y:
+    :return series2:
+    """
+    new_val = val
+    if np.isnan(zref_y['stdev'])==False and zref_y['stdev']>0.0 and np.isnan(zref_x['stdev'])==False and zref_x['stdev']>0.0:
+        new_val *= (zref_y['stdev'] / zref_x['stdev'])
+    return new_val
+
 def bref_encode(series):
     """
     Boolean variables are not encoded at this stage
@@ -197,8 +213,6 @@ def rref_encode_with_keys(df, record_id_var, rref):
         return None, None
     df2 = deepcopy(df)
     df2[record_id_var], rref = xref_encode_with_keys(df[record_id_var], rref)
-    print(rref)
-    print(df2[record_id_var])
     return df2, rref
 
 def rref_decode(df, record_id_var, rref, verbose=False):
@@ -328,7 +342,7 @@ def compute_cluster_stats(df, categorical_fields):
     stats['frequency'] = stats['count']/len(df)
     stats.sort_index(inplace=True)
     stats.index.rename('PC_ID', inplace=True)
-    stats = stats.join(pd.get_dummies(df, columns=categorical_fields).groupby('PC_ID').mean(), on='PC_ID')
+    stats = stats.join(pd.get_dummies(df, columns=categorical_fields).groupby('PC_ID').mean(numeric_only=True), on='PC_ID')
     return stats.T
 
 def compute_cluster_distances(df, categorical_fields):
@@ -338,7 +352,7 @@ def compute_cluster_distances(df, categorical_fields):
     :return distances:
     """
     if df is None: return None
-    df2 = pd.get_dummies(df, columns=categorical_fields).groupby('PC_ID').mean()
+    df2 = pd.get_dummies(df, columns=categorical_fields).groupby('PC_ID').mean(numeric_only=True)
     recs = []
     for idx1, cluster1 in df2.iterrows():
         rec = []
